@@ -22,8 +22,6 @@ from typing import Any, Awaitable, Callable
 
 from prompt_toolkit.formatted_text import FormattedText
 from pydantic import BaseModel, ConfigDict, Field, PrivateAttr, field_validator
-from rich.padding import Padding
-from rich.panel import Panel
 from rich.tree import Tree
 
 from falyx.action.action import Action
@@ -82,7 +80,7 @@ class Command(BaseModel):
         spinner_message (str): Spinner text message.
         spinner_type (str): Spinner style (e.g., dots, line, etc.).
         spinner_style (str): Color or style of the spinner.
-        spinner_kwargs (dict): Extra spinner configuration.
+        spinner_speed (float): Speed of the spinner animation.
         hooks (HookManager): Hook manager for lifecycle events.
         retry (bool): Enable retry on failure.
         retry_all (bool): Enable retry across chained or grouped actions.
@@ -128,7 +126,7 @@ class Command(BaseModel):
     spinner_message: str = "Processing..."
     spinner_type: str = "dots"
     spinner_style: str = OneColors.CYAN
-    spinner_kwargs: dict[str, Any] = Field(default_factory=dict)
+    spinner_speed: float = 1.0
     hooks: "HookManager" = Field(default_factory=HookManager)
     retry: bool = False
     retry_all: bool = False
@@ -286,16 +284,7 @@ class Command(BaseModel):
 
         try:
             await self.hooks.trigger(HookType.BEFORE, context)
-            if self.spinner:
-                with console.status(
-                    self.spinner_message,
-                    spinner=self.spinner_type,
-                    spinner_style=self.spinner_style,
-                    **self.spinner_kwargs,
-                ):
-                    result = await self.action(*combined_args, **combined_kwargs)
-            else:
-                result = await self.action(*combined_args, **combined_kwargs)
+            result = await self.action(*combined_args, **combined_kwargs)
 
             context.result = result
             await self.hooks.trigger(HookType.ON_SUCCESS, context)
@@ -351,35 +340,33 @@ class Command(BaseModel):
         return f"  {command_keys_text:<20}  {options_text} "
 
     @property
-    def help_signature(self) -> tuple[Panel, str]:
+    def help_signature(self) -> tuple[str, str, str]:
         """Generate a help signature for the command."""
         is_cli_mode = self.options_manager.get("mode") in {
             FalyxMode.RUN,
             FalyxMode.PREVIEW,
             FalyxMode.RUN_ALL,
+            FalyxMode.HELP,
         }
 
         program = f"{self.program} run " if is_cli_mode else ""
 
         if self.arg_parser and not self.simple_help_signature:
-            usage = Panel(
-                f"[{self.style}]{program}[/]{self.arg_parser.get_usage()}",
-                expand=False,
-            )
-            description = [f"  {self.help_text or self.description}"]
+            usage = f"[{self.style}]{program}[/]{self.arg_parser.get_usage()}"
+            description = f"[dim]{self.help_text or self.description}[/dim]"
             if self.tags:
-                description.append(f"  [dim]Tags: {', '.join(self.tags)}[/dim]")
-            return usage, "\n".join(description)
+                tags = f"[dim]Tags: {', '.join(self.tags)}[/dim]"
+            else:
+                tags = ""
+            return usage, description, tags
 
         command_keys = " | ".join(
             [f"[{self.style}]{self.key}[/{self.style}]"]
             + [f"[{self.style}]{alias}[/{self.style}]" for alias in self.aliases]
         )
         return (
-            Panel(
-                f"[{self.style}]{program}[/]{command_keys}  {self.description}",
-                expand=False,
-            ),
+            f"[{self.style}]{program}[/]{command_keys}",
+            f"[dim]{self.help_text or self.description}[/dim]",
             "",
         )
 
@@ -387,7 +374,7 @@ class Command(BaseModel):
         if self._context:
             self._context.log_summary()
 
-    def show_help(self) -> bool:
+    def render_help(self) -> bool:
         """Display the help message for the command."""
         if callable(self.custom_help):
             output = self.custom_help()
