@@ -27,17 +27,23 @@ import sys
 from argparse import ArgumentParser, Namespace, _SubParsersAction
 from difflib import get_close_matches
 from functools import cached_property
+from pathlib import Path
 from random import choice
 from typing import Any, Callable
 
 from prompt_toolkit import PromptSession
+from prompt_toolkit.application import get_app
 from prompt_toolkit.formatted_text import StyleAndTextTuples
+from prompt_toolkit.history import FileHistory
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.patch_stdout import patch_stdout
+from prompt_toolkit.shortcuts import CompleteStyle
 from prompt_toolkit.validation import ValidationError
 from rich import box
 from rich.console import Console
 from rich.markdown import Markdown
+from rich.padding import Padding
+from rich.panel import Panel
 from rich.table import Table
 
 from falyx.action.action import Action
@@ -57,6 +63,7 @@ from falyx.exceptions import (
 )
 from falyx.execution_registry import ExecutionRegistry as er
 from falyx.hook_manager import Hook, HookManager, HookType
+from falyx.hooks import spinner_before_hook, spinner_teardown_hook
 from falyx.logger import logger
 from falyx.mode import FalyxMode
 from falyx.options_manager import OptionsManager
@@ -126,7 +133,6 @@ class Falyx:
         title: str | Markdown = "Menu",
         *,
         program: str | None = "falyx",
-        program_style: str = OneColors.WHITE,
         usage: str | None = None,
         description: str | None = "Falyx CLI - Run structured async command workflows.",
         epilog: str | None = None,
@@ -148,10 +154,12 @@ class Falyx:
         custom_table: Callable[[Falyx], Table] | Table | None = None,
         hide_menu_table: bool = False,
         show_placeholder_menu: bool = False,
+        prompt_history_base_dir: Path = Path.home(),
+        enable_prompt_history: bool = False,
     ) -> None:
         """Initializes the Falyx object."""
         self.title: str | Markdown = title
-        self.program: str | None = program
+        self.program: str = program or ""
         self.usage: str | None = usage
         self.description: str | None = description
         self.epilog: str | None = epilog
@@ -184,6 +192,14 @@ class Falyx:
         self.help_command: Command | None = (
             self._get_help_command() if include_help_command else None
         )
+        if enable_prompt_history:
+            program = (self.program or "falyx").split(".")[0].replace(" ", "_")
+            self.history_path: Path = (
+                Path(prompt_history_base_dir) / f".{program}_history"
+            )
+            self.history: FileHistory | None = FileHistory(self.history_path)
+        else:
+            self.history = None
 
     @property
     def is_cli_mode(self) -> bool:
@@ -191,6 +207,7 @@ class Falyx:
             FalyxMode.RUN,
             FalyxMode.PREVIEW,
             FalyxMode.RUN_ALL,
+            FalyxMode.HELP,
         }
 
     def validate_options(
@@ -274,6 +291,7 @@ class Falyx:
             ignore_in_history=True,
             options_manager=self.options,
             program=self.program,
+            help_text="Exit the program.",
         )
 
     def _get_history_command(self) -> Command:
@@ -284,6 +302,7 @@ class Falyx:
             command_style=OneColors.DARK_YELLOW,
             aliases=["HISTORY"],
             program=self.program,
+            options_manager=self.options,
         )
         parser.add_argument(
             "-n",
@@ -334,69 +353,129 @@ class Falyx:
     def get_tip(self) -> str:
         program = f"{self.program} run " if self.is_cli_mode else ""
         tips = [
-            f"Tip: Use '{program}?[KEY]' to preview a command.",
-            f"Tip: Use '{program}?' alone to list all commands at any time.",
-            "Tip: Every command supports aliases—try abbreviating the name!",
-            f"Tip: Use '{program}H' to reopen this help menu anytime.",
-            f"Tip: '{program}[KEY] --help' prints a detailed help message.",
-            "Tip: Mix CLI and menu mode—commands run the same way in both.",
-            f"Tip: Use '{self.program} --never-prompt' to disable all prompts for the [bold italic]entire menu session[/].",
-            f"Tip: Use '{self.program} --verbose' to enable debug logging for a menu session.",
-            f"Tip: '{self.program} --debug-hooks' will trace every before/after hook in action.",
-            f"Tip: Run commands directly from the CLI: '{self.program} run [KEY] [OPTIONS]'.",
+            f"Use '{program}?[COMMAND]' to preview a command.",
+            "Every command supports aliases—try abbreviating the name!",
+            f"Use '{program}H' to reopen this help menu anytime.",
+            f"'{program}[COMMAND] --help' prints a detailed help message.",
+            "[bold]CLI[/] and [bold]Menu[/] mode—commands run the same way in both.",
+            f"'{self.program} --never-prompt' to disable all prompts for the [bold italic]entire menu session[/].",
+            f"Use '{self.program} --verbose' to enable debug logging for a menu session.",
+            f"'{self.program} --debug-hooks' will trace every before/after hook in action.",
+            f"Run commands directly from the CLI: '{self.program} run [COMMAND] [OPTIONS]'.",
+            "All [COMMAND] keys and aliases are case-insensitive.",
         ]
         if self.is_cli_mode:
             tips.extend(
                 [
-                    f"Tip: Use '{self.program} --never-prompt run [KEY]' to disable all prompts for [bold italic]just this command[/].",
-                    f"Tip: Use '{self.program} run --skip-confirm [KEY]' to skip confirmations.",
-                    f"Tip: Use '{self.program} run --summary [KEY]' to print a post-run summary.",
-                    f"Tip: Use '{self.program} --verbose run [KEY]' to enable debug logging for any run.",
-                    "Tip: Use '--skip-confirm' for automation scripts where no prompts are wanted.",
+                    f"Use '{self.program} help' to list all commands at any time.",
+                    f"Use '{self.program} --never-prompt run [COMMAND] [OPTIONS]' to disable all prompts for [bold italic]just this command[/].",
+                    f"Use '{self.program} run --skip-confirm [COMMAND] [OPTIONS]' to skip confirmations.",
+                    f"Use '{self.program} run --summary [COMMAND] [OPTIONS]' to print a post-run summary.",
+                    f"Use '{self.program} --verbose run [COMMAND] [OPTIONS]' to enable debug logging for any run.",
+                    "Use '--skip-confirm' for automation scripts where no prompts are wanted.",
                 ]
             )
         else:
             tips.extend(
                 [
-                    "Tip: '[CTRL+KEY]' toggles are available in menu mode for quick switches.",
-                    "Tip: '[Y]' opens the command history viewer.",
-                    "Tip: Use '[X]' in menu mode to exit.",
+                    "Use '[?]' alone to list all commands at any time.",
+                    "'[CTRL+KEY]' toggles are available in menu mode for quick switches.",
+                    "'[Y]' opens the command history viewer.",
+                    "Use '[X]' in menu mode to exit.",
                 ]
             )
         return choice(tips)
 
-    async def _show_help(self, tag: str = "") -> None:
+    async def _render_help(
+        self, tag: str = "", key: str | None = None, tldr: bool = False
+    ) -> None:
+        if tldr and not key:
+            if self.help_command and self.help_command.arg_parser:
+                self.help_command.arg_parser.render_tldr()
+                self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
+                return None
+        if key:
+            _, command, args, kwargs = await self.get_command(key)
+            if command and tldr and command.arg_parser:
+                command.arg_parser.render_tldr()
+                self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
+                return None
+            elif command and tldr and not command.arg_parser:
+                self.console.print(
+                    f"[bold]No TLDR examples available for '{command.description}'.[/bold]"
+                )
+            elif command and command.arg_parser:
+                command.arg_parser.render_help()
+                self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
+                return None
+            elif command and not command.arg_parser:
+                self.console.print(
+                    f"[bold]No detailed help available for '{command.description}'.[/bold]"
+                )
+            else:
+                self.console.print(f"[bold]No command found for '{key}'.[/bold]")
         if tag:
             tag_lower = tag.lower()
+            self.console.print(f"[bold]{tag_lower}:[/bold]")
             commands = [
                 command
                 for command in self.commands.values()
                 if any(tag_lower == tag.lower() for tag in command.tags)
             ]
+            if not commands:
+                self.console.print(f"'{tag}'... Nothing to show here")
+                return None
             for command in commands:
-                usage, description = command.help_signature
-                self.console.print(usage)
-                if description:
-                    self.console.print(description)
-            return
+                usage, description, _ = command.help_signature
+                self.console.print(
+                    Padding(
+                        Panel(usage, expand=False, title=description, title_align="left"),
+                        (0, 2),
+                    )
+                )
+            self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
+            return None
 
+        self.console.print("[bold]help:[/bold]")
         for command in self.commands.values():
-            usage, description = command.help_signature
-            self.console.print(usage)
-            if description:
-                self.console.print(description)
+            usage, description, tag = command.help_signature
+            self.console.print(
+                Padding(
+                    Panel(
+                        usage,
+                        expand=False,
+                        title=description,
+                        title_align="left",
+                        subtitle=tag,
+                    ),
+                    (0, 2),
+                )
+            )
         if self.help_command:
-            usage, description = self.help_command.help_signature
-            self.console.print(usage)
-            self.console.print(description)
+            usage, description, _ = self.help_command.help_signature
+            self.console.print(
+                Padding(
+                    Panel(usage, expand=False, title=description, title_align="left"),
+                    (0, 2),
+                )
+            )
         if not self.is_cli_mode:
             if self.history_command:
-                usage, description = self.history_command.help_signature
-                self.console.print(usage)
-                self.console.print(description)
-            usage, _ = self.exit_command.help_signature
-            self.console.print(usage)
-        self.console.print(self.get_tip())
+                usage, description, _ = self.history_command.help_signature
+                self.console.print(
+                    Padding(
+                        Panel(usage, expand=False, title=description, title_align="left"),
+                        (0, 2),
+                    )
+                )
+            usage, description, _ = self.exit_command.help_signature
+            self.console.print(
+                Padding(
+                    Panel(usage, expand=False, title=description, title_align="left"),
+                    (0, 2),
+                )
+            )
+        self.console.print(f"[bold]tip:[/bold] {self.get_tip()}")
 
     def _get_help_command(self) -> Command:
         """Returns the help command for the menu."""
@@ -404,8 +483,9 @@ class Falyx:
             command_key="H",
             command_description="Help",
             command_style=OneColors.LIGHT_YELLOW,
-            aliases=["?", "HELP", "LIST"],
+            aliases=["HELP", "?"],
             program=self.program,
+            options_manager=self.options,
         )
         parser.add_argument(
             "-t",
@@ -414,12 +494,28 @@ class Falyx:
             default="",
             help="Optional tag to filter commands by.",
         )
+        parser.add_argument(
+            "-k",
+            "--key",
+            nargs="?",
+            default=None,
+            help="Optional command key or alias to get detailed help for.",
+        )
+        parser.add_tldr_examples(
+            [
+                ("", "Show all commands."),
+                ("-k [COMMAND]", "Show detailed help for a specific command."),
+                ("-Tk [COMMAND]", "Show quick usage examples for a specific command."),
+                ("--tldr", "Show these quick usage examples."),
+                ("--tag [TAG]", "Show commands with the specified tag."),
+            ]
+        )
         return Command(
             key="H",
-            aliases=["?", "HELP", "LIST"],
+            aliases=["HELP", "?"],
             description="Help",
-            help_text="Show this help menu",
-            action=Action("Help", self._show_help),
+            help_text="Show this help menu.",
+            action=Action("Help", self._render_help),
             style=OneColors.LIGHT_YELLOW,
             arg_parser=parser,
             ignore_in_history=True,
@@ -513,8 +609,10 @@ class Falyx:
             placeholder = self.build_placeholder_menu()
             self._prompt_session = PromptSession(
                 message=self.prompt,
+                history=self.history,
                 multiline=False,
                 completer=self._get_completer(),
+                complete_style=CompleteStyle.COLUMN,
                 validator=CommandValidator(self, self._get_validator_error_message()),
                 bottom_toolbar=self._get_bottom_bar_render(),
                 key_bindings=self.key_bindings,
@@ -581,6 +679,7 @@ class Falyx:
         style: str = OneColors.DARK_RED,
         confirm: bool = False,
         confirm_message: str = "Are you sure?",
+        help_text: str = "Exit the program.",
     ) -> None:
         """Updates the back command of the menu."""
         self._validate_command_key(key)
@@ -598,6 +697,7 @@ class Falyx:
             ignore_in_history=True,
             options_manager=self.options,
             program=self.program,
+            help_text=help_text,
         )
 
     def add_submenu(
@@ -611,7 +711,12 @@ class Falyx:
             key, description, submenu.menu, style=style, simple_help_signature=True
         )
         if submenu.exit_command.key == "X":
-            submenu.update_exit_command(key="B", description="Back", aliases=["BACK"])
+            submenu.update_exit_command(
+                key="B",
+                description="Back",
+                aliases=["BACK"],
+                help_text="Go back to the previous menu.",
+            )
 
     def add_commands(self, commands: list[Command] | list[dict]) -> None:
         """Adds a list of Command instances or config dicts."""
@@ -652,7 +757,7 @@ class Falyx:
         spinner_message: str = "Processing...",
         spinner_type: str = "dots",
         spinner_style: str = OneColors.CYAN,
-        spinner_kwargs: dict[str, Any] | None = None,
+        spinner_speed: float = 1.0,
         hooks: HookManager | None = None,
         before_hooks: list[Callable] | None = None,
         success_hooks: list[Callable] | None = None,
@@ -702,7 +807,7 @@ class Falyx:
             spinner_message=spinner_message,
             spinner_type=spinner_type,
             spinner_style=spinner_style,
-            spinner_kwargs=spinner_kwargs or {},
+            spinner_speed=spinner_speed,
             tags=tags if tags else [],
             logging_hooks=logging_hooks,
             retry=retry,
@@ -737,6 +842,10 @@ class Falyx:
         for hook in teardown_hooks or []:
             command.hooks.register(HookType.ON_TEARDOWN, hook)
 
+        if spinner:
+            command.hooks.register(HookType.BEFORE, spinner_before_hook)
+            command.hooks.register(HookType.ON_TEARDOWN, spinner_teardown_hook)
+
         self.commands[key] = command
         return command
 
@@ -854,17 +963,13 @@ class Falyx:
                 logger.info("Command '%s' selected.", run_command.key)
             if is_preview:
                 return True, run_command, args, kwargs
-            elif self.options.get("mode") in {
-                FalyxMode.RUN,
-                FalyxMode.RUN_ALL,
-                FalyxMode.PREVIEW,
-            }:
+            elif self.is_cli_mode:
                 return False, run_command, args, kwargs
             try:
                 args, kwargs = await run_command.parse_args(input_args, from_validate)
             except (CommandArgumentError, Exception) as error:
                 if not from_validate:
-                    run_command.show_help()
+                    run_command.render_help()
                     self.console.print(
                         f"[{OneColors.DARK_RED}]❌ [{run_command.key}]: {error}"
                     )
@@ -934,6 +1039,9 @@ class Falyx:
 
     async def process_command(self) -> bool:
         """Processes the action of the selected command."""
+        app = get_app()
+        await asyncio.sleep(0.1)
+        app.invalidate()
         with patch_stdout(raw=True):
             choice = await self.prompt_session.prompt_async()
         is_preview, selected_command, args, kwargs = await self.get_command(choice)
@@ -1104,7 +1212,59 @@ class Falyx:
         subparsers: _SubParsersAction | None = None,
         callback: Callable[..., Any] | None = None,
     ) -> None:
-        """Run Falyx CLI with structured subcommands."""
+        """
+        Entrypoint for executing a Falyx CLI application via structured subcommands.
+
+        This method parses CLI arguments, configures the runtime environment, and dispatches
+        execution to the appropriate command mode:
+
+        - help - Show help output, optionally filtered by tag.
+        - version - Print the program version and exit.
+        - preview - Display a preview of the specified command without executing it.
+        - run - Execute a single command with parsed arguments and lifecycle hooks.
+        - run-all - Run all commands matching a tag concurrently (with default args).
+        - (default) - Launch the interactive Falyx menu loop.
+
+        It also applies CLI flags such as `--verbose`, `--debug-hooks`, and summary reporting,
+        and supports an optional callback for post-parse setup.
+
+        Args:
+            falyx_parsers (FalyxParsers | None):
+                Preconfigured argument parser set. If not provided, a default parser
+                is created using the registered commands and passed-in `root_parser`
+                or `subparsers`.
+            root_parser (ArgumentParser | None):
+                Optional root parser to merge into the CLI (used if `falyx_parsers`
+                is not supplied).
+            subparsers (_SubParsersAction | None):
+                Optional subparser group to extend (used if `falyx_parsers` is not supplied).
+            callback (Callable[..., Any] | None):
+                An optional function or coroutine to run after parsing CLI arguments,
+                typically for initializing logging, environment setup, or other
+                pre-execution configuration.
+
+        Raises:
+            FalyxError:
+                If invalid parser objects are supplied, or CLI arguments conflict
+                with the expected run mode.
+            SystemExit:
+                Exits with an appropriate exit code based on the selected command
+                or signal (e.g. Ctrl+C triggers exit code 130).
+
+        Notes:
+            - `run-all` executes all tagged commands **in parallel** and does not
+            supply arguments to individual commands; use `ChainedAction` or explicit
+            CLI calls for ordered or parameterized workflows.
+            - Most CLI commands exit the process via `sys.exit()` after completion.
+            - For interactive sessions, this method falls back to `menu()`.
+
+        Example:
+            ```
+            >>> flx = Falyx()
+            >>> await flx.run()   # Parses CLI args and dispatches appropriately
+            ```
+        """
+
         if self.cli_args:
             raise FalyxError(
                 "Run is incompatible with CLI arguments. Use 'run_key' instead."
@@ -1147,8 +1307,11 @@ class Falyx:
             logger.debug("Enabling global debug hooks for all commands")
             self.register_all_with_debug_hooks()
 
-        if self.cli_args.command == "list":
-            await self._show_help(tag=self.cli_args.tag)
+        if self.cli_args.command == "help":
+            self.options.set("mode", FalyxMode.HELP)
+            await self._render_help(
+                tag=self.cli_args.tag, key=self.cli_args.key, tldr=self.cli_args.tldr
+            )
             sys.exit(0)
 
         if self.cli_args.command == "version" or self.cli_args.version:
@@ -1187,7 +1350,7 @@ class Falyx:
                 sys.exit(0)
             except CommandArgumentError as error:
                 self.console.print(f"[{OneColors.DARK_RED}]❌ ['{command.key}'] {error}")
-                command.show_help()
+                command.render_help()
                 sys.exit(1)
             try:
                 await self.run_key(self.cli_args.name, args=args, kwargs=kwargs)
@@ -1196,13 +1359,13 @@ class Falyx:
                 sys.exit(1)
             except QuitSignal:
                 logger.info("[QuitSignal]. <- Exiting run.")
-                sys.exit(0)
+                sys.exit(130)
             except BackSignal:
                 logger.info("[BackSignal]. <- Exiting run.")
-                sys.exit(0)
+                sys.exit(1)
             except CancelSignal:
                 logger.info("[CancelSignal]. <- Exiting run.")
-                sys.exit(0)
+                sys.exit(1)
 
             if self.cli_args.summary:
                 er.summary()
@@ -1227,22 +1390,35 @@ class Falyx:
                 f"{self.cli_args.tag}"
             )
 
-            for cmd in matching:
-                self._set_retry_policy(cmd)
-                try:
-                    await self.run_key(cmd.key)
-                except FalyxError as error:
-                    self.console.print(f"[{OneColors.DARK_RED}]❌ Error: {error}[/]")
-                    sys.exit(1)
-                except QuitSignal:
+            tasks = []
+            try:
+                for cmd in matching:
+                    self._set_retry_policy(cmd)
+                    tasks.append(self.run_key(cmd.key))
+            except Exception as error:
+                self.console.print(
+                    f"[{OneColors.DARK_RED}]❌ Unexpected error: {error}[/]"
+                )
+                sys.exit(1)
+
+            had_errors = False
+            results = await asyncio.gather(*tasks, return_exceptions=True)
+            for result in results:
+                if isinstance(result, QuitSignal):
                     logger.info("[QuitSignal]. <- Exiting run.")
-                    sys.exit(0)
-                except BackSignal:
-                    logger.info("[BackSignal]. <- Exiting run.")
-                    sys.exit(0)
-                except CancelSignal:
-                    logger.info("[CancelSignal]. <- Exiting run.")
-                    sys.exit(0)
+                    sys.exit(130)
+                elif isinstance(result, CancelSignal):
+                    logger.info("[CancelSignal]. <- Execution cancelled.")
+                    sys.exit(1)
+                elif isinstance(result, BackSignal):
+                    logger.info("[BackSignal]. <- Back signal received.")
+                    sys.exit(1)
+                elif isinstance(result, FalyxError):
+                    self.console.print(f"[{OneColors.DARK_RED}]❌ Error: {result}[/]")
+                    had_errors = True
+
+            if had_errors:
+                sys.exit(1)
 
             if self.cli_args.summary:
                 er.summary()
